@@ -296,7 +296,7 @@ my $OBSOLETE_PATHS = Lintian::Data->new(
         };
     });
 
-sub run {
+sub always {
     my ($pkg, $type, $info, $proc, $group) = @_;
     my ($is_python, $is_perl, $has_binary_perl_file, $has_public_executable,
         $has_public_shared_library, $build_path);
@@ -820,16 +820,6 @@ sub run {
             elsif ($fname =~ m,^usr/lib/sgml/\S,) {
                 tag 'file-in-usr-lib-sgml', $file;
             }
-            # ---------------- /usr/lib/node
-            elsif ($fname =~ m,^usr/(?:share|lib(?:/[^/]+)?)/nodejs/,) {
-                tag 'nodejs-module-installed-in-usr-lib', $file
-                  if $fname =~ m#usr/lib/nodejs/.*# and $file->is_file;
-                if ($fname
-                    =~ m#usr/(?:share|lib(?:/[^/]+)?)/nodejs/(?:package\.json|[^/]*\.js)$#
-                ) {
-                    tag 'node-package-install-in-nodejs-rootdir', $fname;
-                }
-            }
             # ---------------- perllocal.pod
             elsif ($fname =~ m,^usr/lib/perl.*/perllocal.pod$,) {
                 tag 'package-installs-perllocal-pod', $file;
@@ -2399,7 +2389,7 @@ sub get_checks_for_file {
       and $info->field('section', '') ne 'debian-installer'
       and none { $_ eq $source_pkg } qw(base-files dpkg lintian);
 
-    $checks{'file-references-package-build-path'} = $build_path
+    $checks{'file-references-package-build-path'} = quotemeta($build_path)
       if defined $build_path && $build_path =~ m,^/.+,g;
 
     # If we have a /usr/sbin/foo, check for references to /usr/bin/foo
